@@ -8,7 +8,7 @@
 
 
 from IPython.display import display, Javascript, HTML
-import time
+from os import path
 
 from .CellManager import CellManager, Cell
 from .CommManager import CommManager
@@ -33,7 +33,9 @@ class JupyterNotebook():
     '''
     def __init__(self):
         # Load JS file to notebook, allows for all scripts to access JS functionality
-        display(HTML("<script type='text/javascript'>" + open(".Client.js").read() + "</script>"))
+        module_directory = path.abspath(path.dirname(__file__))
+        js_data = open(path.join(module_directory, 'Client.js')).read()
+        display(HTML(f"<script type='text/javascript'>{js_data}</script>"))
         # Set up managers
         self._data_mgr = DataManager()
         self._cell_mgr = CellManager()
